@@ -63,20 +63,20 @@ icd10cm_get_all_defined <- function(save_data = FALSE, offline = TRUE) {
   # there are some non-numeric characters scattered around)
   sc_lookup <- icd10_generate_subchap_lookup()
   icd10cm2016[["sub_chapter"]] <- merge(x = icd10cm2016["three_digit"], y = sc_lookup,
-        by.x = "three_digit", by.y = "sc_major", all.x = TRUE)[["sc_desc"]]
+                                        by.x = "three_digit", by.y = "sc_major", all.x = TRUE)[["sc_desc"]]
   chap_lookup <- icd10_generate_chap_lookup()
   icd10cm2016[["chapter"]] <- merge(icd10cm2016["three_digit"], chap_lookup,
-        by.x = "three_digit", by.y = "chap_major", all.x = TRUE)[["chap_desc"]]
+                                    by.x = "three_digit", by.y = "chap_major", all.x = TRUE)[["chap_desc"]]
   if (save_data)
     save_in_data_dir(icd10cm2016)
   invisible(icd10cm2016)
 }
 
 icd10_generate_subchap_lookup <- function(lk_majors, verbose = FALSE) {
-  lk_majors <- unique(icd::icd10cm2016[["three_digit"]])
+  lk_majors <- unique(icd10cm2016[["three_digit"]])
   sc_lookup <- data.frame(major = NULL, desc = NULL)
-  for (scn in names(icd::icd10_sub_chapters)) {
-    sc <- icd::icd10_sub_chapters[[scn]]
+  for (scn in names(icd10_sub_chapters)) {
+    sc <- icd10_sub_chapters[[scn]]
     si <- grep(sc["start"], lk_majors)
     se <- grep(sc["end"], lk_majors)
     sc_majors <- lk_majors[si:se]
@@ -92,16 +92,15 @@ icd10_generate_subchap_lookup <- function(lk_majors, verbose = FALSE) {
 }
 
 icd10_generate_chap_lookup <- function(lk_majors) {
-  lk_majors <- unique(icd::icd10cm2016[["three_digit"]])
+  lk_majors <- unique(icd10cm2016[["three_digit"]])
   chap_lookup <- data.frame(major = NULL, desc = NULL)
-  for (chap_n in names(icd::icd10_chapters)) {
-    chap <- icd::icd10_chapters[[chap_n]]
+  for (chap_n in names(icd10_chapters)) {
+    chap <- icd10_chapters[[chap_n]]
     # fix a 2016 error in the CMS XML definitions
     if (chap["end"] == "Y08")
       chap["end"] <- "Y09"
     si <- grep(chap["start"], lk_majors)
     se <- grep(chap["end"], lk_majors)
-
     chap_lookup <- rbind(
       chap_lookup,
       data.frame(chap_major = lk_majors[si:se], chap_desc = chap_n)
@@ -110,4 +109,38 @@ icd10_generate_chap_lookup <- function(lk_majors) {
   chap_lookup
 }
 
+icd10_parse_ahrq_pcs <- function(save_data = TRUE) {
+  f <- unzip_to_data_raw(
+    url = "https://www.hcup-us.ahrq.gov/toolssoftware/procedureicd10/pc_icd10pcs_2018_1.zip",
+    file_name = "pc_icd10pcs_2018.csv", offline = !save_data)
+  dat <- read.csv(file = f$file_path, skip = 1, stringsAsFactors = FALSE,
+                  colClasses = "character", encoding = "latin1")
+  names(dat) <- c("code", "desc", "class_number", "class")
+  dat$class <- factor(dat$class,
+                      levels = c("Minor Diagnostic", "Minor Therapeutic",
+                                 "Major Diagnostic", "Major Therapeutic"))
+  dat$class_number <- NULL
+  dat$code <- gsub(dat$code, pattern = "'", replacement = "")
+  icd10_pcs <- list("2018" = dat[c("code", "desc")])
+  icd10_map_ahrq_pcs <- split(dat$code, dat$class)
+  if (save_data) {
+    save_in_data_dir(icd10_pcs)
+    save_in_data_dir(icd10_map_ahrq_pcs)
+  }
+}
+
+icd10_parse_cms_pcs_all <- function(save_data = TRUE) {
+  for (year in names(icd::icd10_sources)) {
+    var_name <- paste0("icd10_pcs_", year)
+    assign(var_name, icd10_parse_cms_pcs_year(year))
+    save_in_data_dir(var_name)
+  }
+}
+
+icd10_parse_cms_pcs_year <- function(year = "2018") {
+  pcs_file <- icd::icd10_sources[[year]][["pcs_flat"]]
+  pcs_path <- file.path(get_raw_data_dir(), pcs_file)
+  read.fwf(pcs_path, c(5, 8, 2, 62, 120), header = FALSE,
+           col.names = c("count", "pcs", "billable", "short_desc", "long_desc"))
+}
 # nocov end
