@@ -38,19 +38,18 @@
 #' @keywords internal
 unzip_to_data_raw <- function(url, file_name, force = FALSE,
                               verbose = FALSE, offline = TRUE,
-                              data_raw_path = get_raw_data_dir()) {
+                              data_raw_path = get_raw_data_dir(),
+                              save_name = file_name) {
   checkmate::assert_string(url, na.ok = FALSE)
   checkmate::assert_string(file_name, na.ok = FALSE)
   checkmate::assert_flag(offline)
-  # This temporary directory should be cleaned up if run during testing.
-  if (!dir.exists(data_raw_path))
-    data_raw_path <- tempdir()
-  file_path <- file.path(data_raw_path, make.names(file_name))
-  if (verbose)
-    sprintf("file path = %s\nfile name = %s", file_path, file_name)
+  # TODO: This temporary directory should be cleaned up if run during testing.
+  if (!dir.exists(data_raw_path)) data_raw_path <- tempdir()
+  file_path <- file.path(data_raw_path, make.names(save_name))
+  if (verbose) sprintf("file path = %s\nfile name = %s\nsave name = %s",
+                       file_path, file_name, save_name)
   if (force || !file.exists(file_path)) {
-    if (offline)
-      return()
+    if (offline) return()
     stopifnot(
       unzip_single(url = url, file_name = file_name, save_path = file_path)
     )
@@ -68,18 +67,13 @@ download_to_data_raw <- function(
   checkmate::assert_string(url)
   checkmate::assert_string(file_name)
   checkmate::assert_flag(offline)
-  if (!dir.exists(data_raw_path))
-    data_raw_path <- tempdir()
+  if (!dir.exists(data_raw_path)) data_raw_path <- tempdir()
   save_path <- file.path(data_raw_path, file_name)
   f_info <- list(file_path = save_path, file_name = file_name)
-  if (file.exists(save_path))
-    return(f_info)
-  if (offline)
-    return()
+  if (file.exists(save_path)) return(f_info)
+  if (offline) return()
   if (utils::download.file(url = url, destfile = save_path, quiet = TRUE) != 0)
     stop(paste(url, " not downloaded successfully."))
   f_info
-
 }
-
 #nocov end
