@@ -15,8 +15,8 @@ setdiff(AHRQ_comor, Elix_comor)
 setdiff(Elix_comor, AHRQ_comor)
 
 ## ----comparison----------------------------------------------------------
-comp <- icd_diff_comorbid(icd9_map_ahrq, icd9_map_elix, 
-                          show = TRUE, explain = TRUE)
+comp <- diff_comorbid(icd9_map_ahrq, icd9_map_elix, 
+                      show = TRUE, explain = TRUE)
 
 ## ----justCHF-------------------------------------------------------------
 comp$CHF
