@@ -16,9 +16,8 @@
 // along with icd. If not, see <http://www.gnu.org/licenses/>.
 
 // [[Rcpp::interfaces(r, cpp)]]
-//#include <Rcpp.h>                       // for wrap
+#include "icd_types.h"
 #include "attr.h"
-#include <Rcpp.h>             // for Rf_install
 
 //' Set ICD short-form diagnosis code attribute
 //'
