@@ -16,8 +16,8 @@
 // along with icd. If not, see <http://www.gnu.org/licenses/>.
 
 // [[Rcpp::interfaces(r, cpp)]]
+#include "icd_types.h"                 // for ComorbidOut, VecVecInt, VecVec...
 #include "guess.h"
-#include <Rcpp.h>
 #include <vector>
 #include <string>
 #include <algorithm>
