@@ -15,29 +15,73 @@
 // You should have received a copy of the GNU General Public License
 // along with icd. If not, see <http://www.gnu.org/licenses/>.
 
+// [[Rcpp::plugins(cpp11)]]
 #ifndef LOCAL_H_
 #define LOCAL_H_
-
 #include "config.h"
-#include "icd_types.h"                        // for VecInt, VecVecInt, VecV...
+#include "icd_types.h"
 #include <set>
 #include <unordered_map>
 #include <unordered_set>
-
 extern "C" {
 #include "cutil.h"
 #include <cstdlib>
 }
-
-// debugging:
 // #define ICD_DEBUG
 // #define ICD_DEBUG_TRACE
+// #define ICD_DEBUG_UTIL
 // #define ICD_DEBUG_SETUP
 // #define ICD_DEBUG_SETUP_SLOW
 // #define ICD_DEBUG_SETUP_TRACE
 // #define ICD_DEBUG_PARALLEL
 // #define ICD_VALGRIND
 
+#ifdef ICD_DEBUG
+#define DEBUG(x) do { Rcpp::Rcout << x << std::endl; } while (0)
+#else
+#define DEBUG(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG
+#define DEBUG_VEC(x) do { Rcpp::Rcout << #x << ": " << std::flush; printIt(x); } while (0);
+#else
+#define DEBUG_VEC(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG_TRACE
+#define TRACE_VEC(x) do { Rcpp::Rcout << #x << ": " << std::flush; printIt(x); } while (0);
+#else
+#define TRACE_VEC(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG_TRACE
+#define TRACE(x) DEBUG(x)
+#else
+#define TRACE(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG_UTIL
+#define DEBUG_UTIL(x) DEBUG(x)
+#define TRACE_UTIL(x) TRACE(x)
+#define DEBUG_UTIL_VEC(x) DEBUG_VEC(x)
+#else
+#define DEBUG_UTIL(x) ((void)0)
+#define TRACE_UTIL(x) ((void)0)
+#define DEBUG_UTIL_VEC(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG_VALGRIND
+#define DEBUG_VALGRIND(x) DEBUG(x)
+#else
+#define DEBUG_VALGRIND(x) ((void)0)
+#endif
+
+#ifdef ICD_DEBUG_PARALLEL
+#define DEBUG_PARALLEL(x) DEBUG(x)
+#else
+#define DEBUG_PARALLEL(x) ((void)0)
+#endif
+
 // not enough to test whether header is available, because it may be disabled in
 // R: #ifdef _OPENMP
 
@@ -47,26 +91,13 @@ extern "C" {
 #undef ICD_OPENMP
 #endif
 
-#define ICD_EIGEN
-#ifndef HAVE_RCPPEIGEN_H
-#undef ICD_EIGEN
-#endif
-
+//#ifndef HAVE_RCPPEIGEN_H
 #define ICD_CATCH
-#ifndef HAVE_TESTTHAT_H
+// #ifndef HAVE_TESTTHAT_H
+#ifdef NDEBUG
 #undef ICD_CATCH
 #endif
 
-#ifdef ICD_EIGEN
-#include <RcppEigen.h> // also add LinkingTo element in DESCRIPTION to enable
-#include <Eigen/SparseCore>
-// https://eigen.tuxfamily.org/dox/group__TutorialSparse.html
-typedef int SparseValue;
-typedef Eigen::Triplet<SparseValue> Triplet;
-typedef Eigen::SparseMatrix<SparseValue, Eigen::RowMajor> PtsSparse;
-typedef Eigen::MatrixXi DenseMap;
-#endif
-
 #if defined(ICD_VALGRIND) && defined(HAVE_VALGRIND_VALGRIND_H)
 #include <valgrind/callgrind.h>
 #else
@@ -75,42 +106,16 @@ typedef Eigen::MatrixXi DenseMap;
 
 #if (defined ICD_DEBUG || defined ICD_DEBUG_SETUP)
 #include <iostream>
-// only include Rcpp::Rcout if debugging: R won't like cout so we should not do
-// this unless debugging. not so easy to get an iterator for any std container
-// (no common parent class), without Boost
-template<typename VT>
-void printIt(std::vector<VT> v) {
-  typename std::vector<VT>::iterator i;
+template <typename C>
+inline void printIt(const C& c, int n = 10) {
   std::ostringstream o;
-  for (i=v.begin(); i!=v.end(); ++i) {o << *i << " ";}
-  o << "\n";
-  Rcpp::Rcout << o.str();
-  Rcpp::Rcout.flush();
-}
-
-//overload for set
-template<typename ST>
-void printIt(std::set<ST> v) {
-  typename std::set<ST>::iterator i;
-  std::ostringstream o;
-  for (i=v.begin(); i!=v.end(); ++i) {o << *i << " ";}
-  o << "\n";
-  Rcpp::Rcout << o.str();
-  Rcpp::Rcout.flush();
-}
-
-//overload for map
-template<typename MK, typename MV>
-void printIt(std::map<MK,MV> v) {
-  typename std::vector<MK,MV>::iterator i;
-  std::ostringstream o;
-  for (i=v.begin(); i!=v.end(); ++i) {o << *i << " ";}
-  o << "\n";
+  for (int i = 0; i != std::min(n, (int) c.size()); ++i)
+    o << c[i] << " ";
+  o << std::endl;
   Rcpp::Rcout << o.str();
   Rcpp::Rcout.flush();
 }
 
 #endif // end (defined ICD_DEBUG || defined ICD_DEBUG_SETUP)
-
 #endif // LOCAL_H_
 
